GmailSSO class

Constructors

GmailSSO()

Properties

appidpid_shared_preferences int?
getter/setter pair
clientId_shared_preferences String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
idpid_shared_preferences int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

exchangeCodeForTokens(String code, String clientId, String clientSecret, String redirectUri, String tokenEndpoint) Future<Map<String, dynamic>?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendToBackend(String accessToken, String ssoClient) Future<void>
signInWithGoogle(BuildContext context) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited